######################################################################
#
# Chinese Language text and icon macros 
#
######################################################################
#
# This is the main macro file for translation when creating an 
# interface in another language.

# Under the 'text macros' comments are text macros of the form:
# _macroname_ {macro value}
# Everything between the {} is the text to be translated. This text 
# may itself contain macros (i.e. characters other than space between
# underscore characters, e.g. _about:numdocs_ or _textpage_). These
# macro names occurring within text shouldn't be translated but should
# be left as they are. Underscores or curly brackets occurring 
# naturally within the text should be escaped with a leading backslash
# (i.e. '\_', '\{' or '\}).
#
# Under the 'icons' comments are macros concerned with displaying
# icons which themselves contain text.
# Above each macro (or group of macros) for an icon is a comment line
# that looks something like '## "HOME" ## top_nav_button ## chome ##'.
# The first field of the comment ("HOME" in this case) is the text
# that appears in the english version of the icon. This is the text
# that must be translated, nothing needs to be done to the macros 
# themselves. The other two fields of the comments are used by 
# automatic icon generating software which reads the newly translated
# file and generates appropriate icons.
#
# Comment lines (other than those described above) need not be 
# translated (i.e. any lines beginning with '#', like this line).
#
# The simplest way to translate this file is to save it as something
# else (e.g. french.dm) and work through translating all the text
# macro values and icon comments.
#
######################################################################


######################################################################
# Global (base) package
package Global
######################################################################


#------------------------------------------------------------
# text macros
#------------------------------------------------------------

_textperiodicals_ [l=zh] {杂志}
_textsource_ [l=zh] {来源参考：}
_textdate_ [l=zh] {出版日期：}
_textnumpages_ [l=zh] {总页数}

_textsignin_ [l=zh] {登录}

_textdefaultcontent_ [l=zh] {未发现您要求的网页。请用浏览器“后退”键或上面的home键退回绿宝石数字图书馆。}

_textdefaulttitle_ [l=zh] {绿宝石数字图书馆错误}

_textselectpage_ [l=zh] {— 选择页—}

_collectionextra_ [l=zh] {本收藏现有 _about:numdocs_ 文档。 它最近更新与_about:builddate_ 日前。}

# this is only used by the collector (where the above _collectionextra_
# macro will always be set to another value)
_collectorextra_ [l=zh] {<p>本收藏现有_numdocs_ _If_("_numdocs_" eq "1",document,documents), 总共 _numbytes_.
<p><a href="_httppagex_(bsummary)">点击这里</a> 浏览本收藏 build summary 。
}

_textimagecollection_ [l=zh] {}
_textimageabout_ [l=zh] {关于页}
_textimagehome_ [l=zh] {主页}
_textimagehelp_ [l=zh] {帮助页}
_textimagepref_ [l=zh] {选项页}
_textimagegreenstone_ [l=zh] {绿宝石数字图书馆软件}
_textimageusab_ [l=zh] {您在使用中有何困难？}

_textimagesearch_ [l=zh] {特定范围检索}
_textimageTitle_ [l=zh] {按题名排列浏览}
_textimageList_ [l=zh] {按文档排列浏览}
_textimageCreator_ [l=zh] {按作者名顺序浏览}
_textimageSeries_ [l=zh] {按册浏览}
_textimageDate_ [l=zh] {按时间顺序浏览}
_textimageSubject_ [l=zh] {按主题浏览}
_textimageTo_ [l=zh] {按"To"域浏览}
_textimageFrom_ [l=zh] {按From浏览}
_textimageOrganization_ [l=zh] {按组织浏览}
_textimageHowto_ [l=zh] {浏览如何分类}
_textimageTopic_ [l=zh] {浏览特别文章}
_textimageBrowse_ [l=zh] {浏览}
_textimagePeople_ [l=zh] {按人名排列顺序浏览}
_textimageLanguage_ [l=zh] {按语言浏览}
_textimageAcronym_ [l=zh] {浏览词头}
_textimagePhrase_ [l=zh] {浏览短词}
_textimageArtist_ [l=zh] {浏览艺术家}
_textimageSource_ [l=zh] {按原始文件名浏览}
_textimageKeyword_ [l=zh] {按关键词浏览}
_textimageVolume_ [l=zh] {按册次浏览}
_textimageCaptions_ [l=zh] {按图片注释浏览}

_texticontabsearchgreen_ [l=zh] {查询}
_texticontabdategreen_ [l=zh] {日子}
_texticontabseriesgreen_ [l=zh] {系列}
_texticontabauthorgreen_ [l=zh] {作者 A-Z}
_texticontabtitlegreen_ [l=zh] {题名 A-Z}
_texticontablistgreen_ [l=zh] {列表}
_texticontabsubjectgreen_ [l=zh] {主题}
_texticontabtogreen_ [l=zh] {To}
_texticontabfromgreen_ [l=zh] {From}
_texticontaborggreen_ [l=zh] {组织}
_texticontabhowgreen_ [l=zh] {如何}
_texticontabtopicgreen_ [l=zh] {文章}
_texticontabbrwsegreen_ [l=zh] {浏览}
_texticontabbrowsgreen_ [l=zh] {浏览}
_texticontabPeoplegreen_ [l=zh] {人名索引A-Z}
_texticontabLanguagegreen_ [l=zh] {语言}
_texticontabAcronymgreen_ [l=zh] {词头}
_texticontabPhrasegreen_ [l=zh] {短句}
_texticontabArtistgreen_ [l=zh] {艺术家}
_texticontabSourcegreen_ [l=zh] {文件名}
_texticontabKeywordgreen_ [l=zh] {关键词}
_texticontabVolumegreen_ [l=zh] {卷}

_texticontext_ [l=zh] {浏览文章内容}
_texticonclosedbook_ [l=zh] {打开记录并浏览内容}
_texticonnext_ [l=zh] {访问下一单元}
_texticonprev_ [l=zh] {访问前一单元}

_texticonmidi_ [l=zh] {浏览MIDI文档}
_texticonmsword_ [l=zh] {浏览微软Word文档}
_texticonpdf_ [l=zh] {浏览PDF文档}
_texticonps_ [l=zh] {浏览PostScript文档}
_texticonppt_ [l=zh] {浏览PowerPoint文档}
_texticonrtf_ [l=zh] {浏览RTF文档}
_texticonxls_ [l=zh] {浏览微软Excel文档}

_page_ [l=zh] {页}
_pages_ [l=zh] {页}
_of_ [l=zh] {的}
_vol_ [l=zh] {册}
_num_ [l=zh] {否}

_textmonth00_ [l=zh] {}
_textmonth01_ [l=zh] {一月}
_textmonth02_ [l=zh] {二月}
_textmonth03_ [l=zh] {三月}
_textmonth04_ [l=zh] {四月}
_textmonth05_ [l=zh] {五月}
_textmonth06_ [l=zh] {六月}
_textmonth07_ [l=zh] {七月}
_textmonth08_ [l=zh] {八月}
_textmonth09_ [l=zh] {九月}
_textmonth10_ [l=zh] {十月}
_textmonth11_ [l=zh] {十一月}
_textmonth12_ [l=zh] {十二月}

_textdocument_ [l=zh] {文档}
_textsection_ [l=zh] {段落}
_textparagraph_ [l=zh] {段落}

_magazines_ [l=zh] {杂志}

_nzdlpagefooter_ [l=zh] {<p>_iconblankbar_
<p><a href="http://www.nzdl.org">新西兰数字图书馆项目</a>
<br><a href="http://www.cs.waikato.ac.nz/cs">电脑科学系</a>, 
<a href="http://www.waikato.ac.nz">威科图大学</a>, 
新西兰}

#------------------------------------------------------------
# icons
#------------------------------------------------------------

## "主页" ## top_nav_button ## chome ##
_httpiconchomeof_ {_httpimg_/chomeof.gif}
_httpiconchomeon_ {_httpimg_/chomeon.gif}

## "帮助" ## top_nav_button ## chelp ##
_httpiconchelpof_ {_httpimg_/chelpof.gif}
_httpiconchelpon_ {_httpimg_/chelpon.gif}

## "选项" ## top_nav_button ## cpref ##
_httpiconcprefof_ {_httpimg_/cprefof.gif}
_httpiconcprefon_ {_httpimg_/cprefon.gif}

## "回馈信息" ## top_nav_button ## cusab ##
_httpiconcusabof_ {_httpimg_/cusabof.gif}
_httpiconcusabon_ {_httpimg_/cusabon.gif}


## "帮助" ## green_title ## h_help ##
_httpiconhhelp_ {_httpimg_/h\_help.gif}
_widthhhelp_ {200}
_heighthhelp_ {57}

## "作者索引a-z" ## nav_bar_button ## tauth ##
_httpicontauthgr_ {_httpimg_/tauthgr.gif}
_httpicontauthof_ {_httpimg_/tauthof.gif}
_httpicontauthon_ {_httpimg_/tauthon.gif}
_widthtauthx_ {110}

## "标题" ## nav_bar_button ## tcapt ##
_httpicontcaptgr_ {_httpimg_/tcaptgr.gif}
_httpicontcaptof_ {_httpimg_/tcaptof.gif}
_httpicontcapton_ {_httpimg_/tcapton.gif}
_widthtcaptx_ [l=en] {87}

## "集" ## nav_bar_button ## tser ##
_httpicontsergr_ {_httpimg_/tsergr.gif}
_httpicontserof_ {_httpimg_/tserof.gif}
_httpicontseron_ {_httpimg_/tseron.gif}
_widthtserx_ {87}

## "日子" ## nav_bar_button ## tdate ##
_httpicontdategr_ {_httpimg_/tdategr.gif}
_httpicontdateof_ {_httpimg_/tdateof.gif}
_httpicontdateon_ {_httpimg_/tdateon.gif}
_widthtdatex_ {87}

## "主题" ## nav_bar_button ## tsubj ##
_httpicontsubjgr_ {_httpimg_/tsubjgr.gif}
_httpicontsubjon_ {_httpimg_/tsubjon.gif}
_httpicontsubjof_ {_httpimg_/tsubjof.gif}
_widthtsubjx_ {87}

## "to" ## nav_bar_button ## tto ##
_httpiconttogr_ {_httpimg_/ttogr.gif}
_httpiconttoon_ {_httpimg_/ttoon.gif}
_httpiconttoof_ {_httpimg_/ttoof.gif}
_widthttox_ {87}

## "from" ## nav_bar_button ## tfrom ##
_httpicontfromgr_ {_httpimg_/tfromgr.gif}
_httpicontfromon_ {_httpimg_/tfromon.gif}
_httpicontfromof_ {_httpimg_/tfromof.gif}
_widthtfromx_ {87}

## "组织" ## nav_bar_button ## torg ##
_httpicontorggr_{_httpimg_/torggr.gif}
_httpicontorgon_{_httpimg_/torgon.gif}
_httpicontorgof_{_httpimg_/torgof.gif}
_widthtorgx_ {114}

## "如何" ## nav_bar_button ## thow ##
_httpiconthowgr_{_httpimg_/thowgr.gif}
_httpiconthowon_{_httpimg_/thowon.gif}
_httpiconthowof_{_httpimg_/thowof.gif}
_widththowx_ {87}

## "论题" ## nav_bar_button ## ttopic ##
_httpiconttopicgr_{_httpimg_/ttopicgr.gif}
_httpiconttopicon_{_httpimg_/ttopicon.gif}
_httpiconttopicof_{_httpimg_/ttopicof.gif}
_widthttopicx_ {87}

## "浏览" ## nav_bar_button ## tbrwse ##
_httpicontbrwsegr_{_httpimg_/tbrwsegr.gif}
_httpicontbrwseon_{_httpimg_/tbrwseon.gif}
_httpicontbrwseof_{_httpimg_/tbrwseof.gif}
_widthtbrwsex_ {87}

## "查询" ## nav_bar_button ## tsrch ##
_httpicontsrchgr_ {_httpimg_/tsrchgr.gif}
_httpicontsrchof_ {_httpimg_/tsrchof.gif}
_httpicontsrchon_ {_httpimg_/tsrchon.gif}
_widthtsrchx_ {87}

## "题名索引a-z" ## nav_bar_button ## ttitl ##
_httpiconttitlgr_ {_httpimg_/ttitlgr.gif}
_httpiconttitlof_ {_httpimg_/ttitlof.gif}
_httpiconttitlon_ {_httpimg_/ttitlon.gif}
_widthttitlx_ {87}

## "人名" ## nav_bar_button ## tpeop ##
_httpicontpeopgr_ {_httpimg_/tpeopgr.gif}
_httpicontpeopof_ {_httpimg_/tpeopof.gif}
_httpicontpeopon_ {_httpimg_/tpeopon.gif}
_widthtpeopx_ {97}

## "语言" ## nav_bar_button ## tlang ##
_httpicontlanggr_ {_httpimg_/tlanggr.gif}
_httpicontlangon_ {_httpimg_/tlangon.gif}
_httpicontlangof_ {_httpimg_/tlangof.gif}
_widthtlangx_ {87}

## "词头" ## nav_bar_button ## tacro ##
_httpicontacrogr_ {_httpimg_/tacrogr.gif}
_httpicontacroof_ {_httpimg_/tacroof.gif}
_httpicontacroon_ {_httpimg_/tacroon.gif}
_widthtacrox_ {87}

#TODO singular or plural?

## "短句" ## nav_bar_button ## tphrse ##
_httpicontphrsegr_ {_httpimg_/tphrsegr.gif}
_httpicontphrseof_ {_httpimg_/tphrseof.gif}
_httpicontphrseon_ {_httpimg_/tphrseon.gif}
_widthtphrsex_ {87}

## "艺术家" ## nav_bar_button ## tartst ##
_httpicontartstgr_ {_httpimg_/tartstgr.gif}
_httpicontartstof_ {_httpimg_/tartstof.gif}
_httpicontartston_ {_httpimg_/tartston.gif}
_widthtartstx_ {87}

## "文件名" ## nav_bar_button ## tsrc ##
_httpicontsrcgr_ {_httpimg_/tsrcgr.gif}
_httpicontsrcof_ {_httpimg_/tsrcof.gif}
_httpicontsrcon_ {_httpimg_/tsrcon.gif}
_widthtsrcx_ {87}

## "关键词" ## nav_bar_button ## tkw ##
_httpicontkwgr_ {_httpimg_/tkwgr.gif}
_httpicontkwof_ {_httpimg_/tkwof.gif}
_httpicontkwon_ {_httpimg_/tkwon.gif}
_widthtkwx_ {87}

## "卷数" ## nav_bar_button ## tvol ##
_httpicontvolgr_ {_httpimg_/tvolgr.gif}
_httpicontvolof_ {_httpimg_/tvolof.gif}
_httpicontvolon_ {_httpimg_/tvolon.gif}
_widthtvolx_ {87}

## "译者" ## top_nav_button ## ctrans ##
_httpiconctransof_ {_httpimg_/en/ctransof.gif}
_httpiconctranson_ {_httpimg_/en/ctranson.gif}
_widthctrans_ {100}


######################################################################
# 'about' page
package about
######################################################################


#------------------------------------------------------------
# text macros
#------------------------------------------------------------

_textabcol_ [l=zh] {关于本收藏}

_textsubcols1_ [l=zh] {<p> 此全部收藏由 _1_ subcollections 组成。 
它们在：
<blockquote>}

_textsubcols2_ [l=zh] {</blockquote>
您可以在选项页查询（并修改）现使用的集。}


#------------------------------------------------------------
# icons
#------------------------------------------------------------

## "关于" ## green_title ## h_about ##
_httpiconhabout_ {_httpimg_/h\_about.gif}
_widthhabout_ {200}
_heighthabout_ {57}



######################################################################
# document package
package document
######################################################################


#------------------------------------------------------------
# text macros
#------------------------------------------------------------

_texticonhtitle_ [l=zh] {标题索引A-Z}
_texticonhauth_ [l=zh] {作者索引A-Z}
_texticonhsubj_ [l=zh] {主题}
_texticonhto_ [l=zh] {To}
_texticonhfrom_ [l=zh] {From}
_texticonhser_ [l=zh] {丛书}
_texticonhdate_ [l=zh] {日期}
_texticonhhow_ [l=zh] {如何}
_texticonhorg_ [l=zh] {组织}
_texticonhbrwse_ [l=zh] {浏览}
_texticonhbrows_ [l=zh] {浏览}
_texticonhpeople_ [l=zh] {人名索引A-Z}
_texticonhlanguage_ [l=zh] {语言}
_texticonhacronym_ [l=zh] {词头}
_texticonhphrases_ [l=zh] {短句}
_texticonhartist_ [l=zh] {艺术家}
_texticonhsrc_ [l=zh] {文件名}
_texticonhkw_ [l=zh] {关键词}
_texticonhvol_ [l=zh] {卷数}

_texticonopenbookshelf_ [l=zh] {关闭图书馆此部分}
_texticonclosedbookshelf_ [l=zh] {打开图书馆此节并且浏览内容}
_texticonopenbook_ [l=zh] {关闭本书}
_texticonclosedfolder_ [l=zh] {打开此文件夹以浏览目录}
_texticonclosedfolder2_ [l=zh] {打开此节：}
_texticonopenfolder_ [l=zh] {关闭此文件夹}
_texticonopenfolder2_ [l=zh] {关闭此节：}
_texticonsmalltext_ [l=zh] {　浏览此部份文本}
_texticonsmalltext2_ [l=zh] {浏览文本：}
_texticonpointer_ [l=zh] {本节}
_texticondetach_ [l=zh] {在一个新的窗口显示本页}
_texticonhighlight_ [l=zh] {　突出显示查询项}
_texticonnohighlight_ [l=zh] {不要突出显示查询项}
_texticoncontracttoc_ [l=zh] {打开目录}
_texticonexpandtoc_ [l=zh] {　扩展书录表}
_texticonexpandtext_ [l=zh] {　显示所有文本}
_texticoncontracttext_ [l=zh] {对选定的段落只显示文字}
_texticonwarning_ [l=zh] {<b>警告：</b>}
_texticoncont_ [l=zh] {继续？}

_textltwarning_ [l=zh] {<p><center>
<table cellspacing=0 cellpadding=0 width=_pagewidth_>
<tr valign=top><td>_iconwarning_展开此文本将会在您的浏览器产生大量的数据来显示 _imagecont_
</td></tr></table></center>
}

_textgoto_ [l=zh] {链接到页}
_textintro_ [l=zh] {<i>(介绍文本)</i>}


#------------------------------------------------------------
# icons
#------------------------------------------------------------

## "标题索引a-z" ## green_title ## h_title ##
_httpiconhtitle_ {_httpimg_/h\_title.gif}
_widthhtitle_ {200}
_heighthtitle_ {57}

## "作者索引a-z" ## green_title ## h_auth ##
_httpiconhauth_ {_httpimg_/h\_auth.gif}
_widthhauth_ {200}
_heighthauth_ {57}

## "主题" ## green_title ## h_subj ##
_httpiconhsubj_ {_httpimg_/h\_subj.gif}
_widthhsubj_ {200}
_heighthsubj_ {57}

# -- Missing translation: h_to

# -- Missing translation: h_from

## "丛书" ## green_title ## h_ser ##
_httpiconhser_ {_httpimg_/h\_ser.gif}
_widthhser_ {200}
_heighthser_ {57}

## "日子" ## green_title ## h_date ##
_httpiconhdate_ {_httpimg_/h\_date.gif}
_widthhdate_ {200}
_heighthdate_ {57}

## "如何" ## green_title ## h_how ##
_httpiconhhow_ {_httpimg_/h\_how.gif}
_widthhhow_ {200}
_heighthhow_ {57}

## "标题" ## green_title ## h_topic ##
_httpiconhtopic_ {_httpimg_/h\_topic.gif}
_widthhtopic_ {200}
_heighthtopic_ {57}

## "组织" ## green_title ## h_org ##
_httpiconhorg_ {_httpimg_/h\_org.gif}
_widthhorg_ {250}
_heighthorg_ {57}

## "浏览" ## green_title ## h_brwse ##
_httpiconhbrwse_ {_httpimg_/h\_brwse.gif}
_widthhbrwse_ {200}
_heighthbrwse_ {57}

## "人" ## green_title ## h_people ##
_httpiconhpeople_ {_httpimg_/h\_people.gif}
_widthhpeople_ {200}
_heighthpeople_ {57}

## "语言" ## green_title ## h_lang ##
_httpiconhlanguage_ {_httpimg_/h\_lang.gif}
_widthhlanguage_ {200}
_heighthlanguage_ {57}

## "词头" ## green_title ## h_acro ##
_httpiconhacronym_ {_httpimg_/h\_acro.gif}
_widthhacronym_ {200}
_heighthacronym_ {57}

## "短句" ## green_title ## h_phrse ##
_httpiconhphrse_ {_httpimg_/h\_phrse.gif}
_widthhphrse_ {200}
_heighthphrse_ {57}

## "艺术家" ## green_title ## h_artist ##
_httpiconhartist_ {_httpimg_/h\_artist.gif}
_widthhartist_ {200}
_heighthartist_ {57}

## "文件名" ## green_title ## h_src ##
_httpiconhsrc_ {_httpimg_/h\_src.gif}
_widthhsrc_ {200}
_heighthsrc_ {57}

## "关键词" ## green_title ## h_kw ##
_httpiconhkw_ {_httpimg_/h\_kw.gif}
_widthhkw_ {200}
_heighthkw_ {57}

## "卷数" ## green_title ## h_vol ##
_httpiconhvol_ {_httpimg_/h\_vol.gif}
_widthhvol_ {200}
_heighthvol_ {57}

## "标题" ## green_title ## h_capt ##
_httpiconhcapt_ {_httpimg_/h\_capt.gif}
_widthhcapt_ {200}
_heighthcapt_ {57}


## "继续？?" ## top_nav_button ## cont ##
_httpiconcontoff_ {_httpimg_/contof.gif}
_httpiconconton_ {_httpimg_/conton.gif}

## "展开TEXT" ## document_button ## eallt ## 
_httpiconealltof_ {_httpimg_/ealltof.gif}
_httpiconeallton_ {_httpimg_/eallton.gif}

## "收缩内容" ## document_button ## econc ##
_httpiconeconcof_ {_httpimg_/econcof.gif}
_httpiconeconcon_ {_httpimg_/econcon.gif}

## "脱离" ## document_button ## edtch ##
_httpiconedtchof_ {_httpimg_/edtchof.gif}
_httpiconedtchon_ {_httpimg_/edtchon.gif}

## "展开内容" ## document_button ## eexpc ##
_httpiconeexpcof_ {_httpimg_/eexpcof.gif}
_httpiconeexpcon_ {_httpimg_/eexpcon.gif}

## "收缩文本" ## document_button ## etsec ##
_httpiconetsecof_ {_httpimg_/etsecof.gif}
_httpiconetsecon_ {_httpimg_/etsecon.gif}

## "突出显示" ## document_button ## ehl ##
_httpiconehlof_ {_httpimg_/ehlof.gif}
_httpiconehlon_ {_httpimg_/ehlon.gif}

## "不突出显示" ## document_button ## enhl ##
_httpiconenhlof_ {_httpimg_/enhlof.gif}
_httpiconenhlon_ {_httpimg_/enhlon.gif}


######################################################################
# 'search' page
package query
######################################################################


#------------------------------------------------------------
# text macros
#------------------------------------------------------------

# this if statement produces the text 'results n1 - nn for query: querystring' or 
# 'No matches for query: querystring', depending on whether or not there were
# any matches
_textquerytitle_ [l=zh] {_If_(_thislast_,results _thisfirst_ - _thislast_ 查询: _cgiargq_,未发现: _cgiargq_)}
_textnoquerytitle_ [l=zh] {查找页}

_texticonthispage_ [l=zh] {查询}
_textsome_ [l=zh] {部分}
_textall_ [l=zh] {全部}
_textboolean_ [l=zh] {布尔}
_textranked_ [l=zh] {排名}
_textnatural_ [l=zh] {自然}
#_textsome_ {_If_(_cgiargb_,ranked,some)}
#_textall_ {_If_(_cgiargb_,boolean,all)}
#_textformsome_ {_If_(_cgiargb_,ranked,some)}
#_textformall_ {_If_(_cgiargb_,natural,all)}
_texticonqueryresultsbar_ [l=zh] {}
_texticonsearchhistorybar_ [l=zh] {查询历史}

#alt text for query buttons
_textusequery_ [l=zh] {使用此查询}
_textfreqmsg1_ [l=zh] {词语总计：}
_textpostprocess_ [l=zh] {_If_(_quotedquery_,<br><i>后处理去发现_quotedquery_</i>
)}
_textinvalidquery_ [l=zh] {非法的搜寻语法}

_textmorethan_ [l=zh] {多于}
_textapprox_ [l=zh] {关于}
_textnodocs_ [l=zh] {没有文档符合搜寻条件。}
_text1doc_ [l=zh] {1个文档符合查询条件。}
_textlotsdocs_ [l=zh] {文档匹配搜寻条件。}
_textmatches_ [l=zh] {匹配 }
_textbeginsearch_ [l=zh] {开始查询}
_textrunquery_ [l=zh] {执行查询}
_textclearform_ [l=zh] {清除表格}

#these go together in form search:
#"Word or phrase  (fold, stem)  ... in field"
_textwordphrase_ [l=zh] {词或短句}
_textinfield_ [l=zh] {… 在域}
_textfoldstem_ [l=zh] {(文件夹, 部分匹配？)}

_textadvquery_ [l=zh] {或者直接输入查询语句：}
_textallfields_ [l=zh] {全部}
_texttextonly_ [l=zh] {只限文本}
_textand_ [l=zh] {"与“运算}
_textor_ [l=zh] {或者}
_textandnot_ [l=zh] {“与否”运算}

# _hselection_, _jselection_, _nselection_ and _gselection_ are set from 
# within the server some or all of them may remain unset


_textsimplesearch_ [l=zh] {按 _If_(_hselection_, _hselection_)_If_(_jselection_,_textjselect_)_If_(_nselection_, in _nselection_ language) 
查询包含 _querytypeselection_ 提问词的记录}

_textadvancedsearch_ [l=zh] {_If_(_hselection_, _hselection_, _defaultindextext_) _If_(_jselection_,_textjselect_) _If_(_gselection_, at _gselection_ level)_If_(_nselection_, in _nselection_ language) 
使用 _querytypeselection_ 语句查询}

#have changed mgpp search headers
_textsimplesearchmgpp_ [l=zh] {按 _If_(_fqfselection_, _fqfselection_) _If_(_jselection_, _textjselect_) _If_(_gselection_, at _gselection_ level) _If_(_nselection_, in _nselection_ language)
查询包含 _querytypeselection_ 词。}

_textadvancedsearchmgpp_ [l=zh] {_If_(_fqfselection_, _fqfselection_, _defaultindextext_) _If_(_jselection_,_textjselect_) _If_(_gselection_, at _gselection_ level)_If_(_nselection_, in _nselection_ language) 
使用_querytypeselection_ 语句查询}

_textformsimplesearch_ [l=zh] { _If_(_jselection_, _textjselection_) _If_(_gformselection_, at _gformselection_ level) _If_(_nselection_, in _nselection_ language)
以 _formquerytypeselection_ 查询}

_textformadvancedsearch_ [l=zh] { _If_(_jselection_,_jselection_) _If_(_gformselection_, at _gformselection_ level)_If_(_nselection_, in _nselection_ language) 
查询并且以 _formquerytypeselection_ order 显示结果}

_textjselect_ [l=zh] {_If_(_hselection_, of) _jselection_}

_textnojsformwarning_ [l=zh] {警告：您浏览器的Javascript被禁用了。 <br>要使用查询功能，请启用它。}
_textdatesearch_ [l=zh] {本收藏可以按日期范围或包含一个特定的日子来进行查询.这是查询的一项可选择功能.}
_textstartdate_ [l=zh] {开始（或限制）日期：}
_textenddate_ [l=zh] {完成日期：}
# -- Missing translation: _textbc_
# -- Missing translation: _textad_
_textexplaineras_ [l=zh] {C.E. 和 B.C.E 同公元(A.D.)和公元前(B.C.)的一样意思. 这些词语被认为是文化差异, 表示"现在" 和"先于现在".}

_textstemon_ [l=zh] {（忽略词尾）}

_textsearchhistory_ [l=zh] {查询历史}

#text macros for search history
_textnohistory_ [l=zh] {查询历史不存在}
_texthresult_ [l=zh] {结果}
_texthresults_ [l=zh] {结果}
_texthallwords_ [l=zh] {所有词语}
_texthsomewords_ [l=zh] {一些词语}
_texthboolean_ [l=zh] {布尔}
_texthranked_ [l=zh] {排名}
_texthcaseon_ [l=zh] {大小写必须匹配}
# -- Missing translation: _texthcaseoff_
_texthstemon_ [l=zh] {部分匹配？}
_texthstemoff_ [l=zh] {全部匹配？}

#------------------------------------------------------------
# icons
#------------------------------------------------------------

## "查询" ## green_title ## h_search ##
_httpiconhsearch_ {_httpimg_/h\_search.gif}
_widthhsearch_ {200}
_heighthsearch_ {57}

## "结果" ## green_bar_left_aligned ## qryresb ##
_httpiconqryresb_ {_httpimg_/qryresb.gif}
_widthqryresb_ {_pagewidth_}
_heightqryresb_ {17}

## "历史纪录" ## green_bar_left_aligned ## schhistb ##
_httpiconsrchhistb_ {_httpimg_/schhistb.gif}
_widthsrchhistb_ {_pagewidth_}
_heightsrchhistb_ {17}


######################################################################
# 'preferences' page
package preferences
######################################################################


#------------------------------------------------------------
# text macros
#------------------------------------------------------------

_textprefschanged_ [l=zh] {选项已经按以下设定. 请不要使用浏览器的"后退"键 - 这样的话将会重新设置选项. 请点击上面的查阅条的按键.
}
_textsetprefs_ [l=zh] {设置选项}
_textsearchprefs_ [l=zh] {查询选项}
_textcollectionprefs_ [l=zh] {收藏选项}
_textpresentationprefs_ [l=zh] {显示选项}
_textpreferences_ [l=zh] {选项}
_textcasediffs_ [l=zh] {区分大小写：}
_textignorecase_ [l=zh] {忽略大小写}
_textmatchcase_ [l=zh] {大写/小写必须匹配}
_textwordends_ [l=zh] {词结尾}
_textstem_ [l=zh] {忽略词结尾}
_textnostem_ [l=zh] {必须匹配全部词}
_textprefop_ [l=zh] {查询最多返回　
　 _maxdocoption_ 记录，每页返回
_hitsperpageoption_ 记录}
_textextlink_ [l=zh] {查阅外部网页：}
_textintlink_ [l=zh] {发现源文档由：}
_textlanguage_ [l=zh] {界面语言：}
_textencoding_ [l=zh] {编码方式：}
_textformat_ [l=zh] {界面格式：}
_textall_ [l=zh] {全部}
_textquerymode_ [l=zh] {查询模式:}
_textsimplemode_ [l=zh] {简单查询方式}
_textadvancedmode_ [l=zh] {高级查询方式(可以使用 !、&、| 和括号来进行布尔查询)}
_textlinkinterm_ [l=zh] {由中间页}
_textlinkdirect_ [l=zh] {直接链接到}
_textdigitlib_ [l=zh] {数字图书馆}
_textweb_ [l=zh] {网}
_textgraphical_ [l=zh] {图形的}
_texttextual_ [l=zh] {文字的}
_textcollectionoption_ [l=zh] {<p>
下级收藏包括:
<br>}

_textrelateddocdisplay_ [l=zh] {显示相关的文档}
_textsearchhistory_ [l=zh] {查询历史}
_textnohistory_ [l=zh] {无查询历史}
_texthistorydisplay_ [l=zh] {显示过去 _historynumrecords_查询}
_textnohistorydisplay_ [l=zh] {不显示查询历史}

#_texttypesearch_ {Type of search:}
#_texttextsearch_ {text search}
_textformsearch_ [l=zh] {表格查询：}
_textplainsearch_ [l=zh] {单一查询}
_textqueryboxsize_ [l=zh] {查询框尺寸:}
_textregbox_ [l=zh] {一般查询框}
_textbigbox_ [l=zh] {较大查询框}
_textformtype_ [l=zh] {表格类型：}
_textsimple_ [l=zh] {简单}
_textadvanced_ [l=zh] {高级的}

# used in "with 4 fields" in the form search box
_textwith_ [l=zh] {和}
_textfields_ [l=zh] {域}


#------------------------------------------------------------
# icons
#------------------------------------------------------------

## "选项" ## green_title ## h_pref ##
_httpiconhpref_ {_httpimg_/h\_pref.gif}
_widthhpref_ {200}
_heighthpref_ {57}

#####################################################################
# 'browse' package for the dynamic browsing interface
package browse
#####################################################################

_textsortby_ [l=zh] {排列文档按}
_textalsoshowing_ [l=zh] {还显示}
_textwith_ [l=zh] {最多以}
_textdocsperpage_ [l=zh] {文档中每页}

_textfilterby_ [l=zh] {文档包含}
_textall_ [l=zh] {全部}
_textany_ [l=zh] {任何}
_textwords_ [l=zh] {词的}
_textleaveblank_ [l=zh] {不选此项以获得所有文档}

_browsebuttontext_ [l=zh] {“文档排序”}

_nodata_ [l=zh] {<i>无数据</i>}
_docs_ [l=zh] {文档}
######################################################################
# 'help' page -- this is lower priority for translating than the
# rest of this file
package help
######################################################################


#------------------------------------------------------------
# text macros
#------------------------------------------------------------

_textHelp_ [l=zh] {帮助}
_textSearchshort_ [l=zh] {按特定词语查找}
_textSeriesshort_ [l=zh] {按丛书查阅出版物}
_textDateshort_ [l=zh] {按日期查阅出版物}
_textSubjectshort_ [l=zh] {按主题查阅出版物}
_textToshort_ [l=zh] {按“To"选项查阅出版物}
_textFromshort_ [l=zh] {按送出人查阅出版物}
_textTitleshort_ [l=zh] {按标题查阅出版物}
_textBrowseshort_ [l=zh] {浏览出版物}
_textCreatorshort_ [l=zh] {按作者查阅出版物}
_textOrganizationshort_ [l=zh] {按组织查阅出版物}
_textHowtoshort_ [l=zh] {按“如何”功能排列查阅出版物}
_textTopicshort_ [l=zh] {按论题查阅出版物}
_textPeopleshort_ [l=zh] {按人物查阅出版物}
_textLanguageshort_ [l=zh] {按语言查阅出版物}
_textAcronymshort_ [l=zh] {按词头查阅出版物}
_textPhraseshort_ [l=zh] {按短语出现查阅出版物}
_textArtistshort_ [l=zh] {按作家出版物查阅}
_textSourceshort_ [l=zh] {按文件名查阅出版物}
_textKeywordshort_ [l=zh] {按关键词查阅出版物}
_textVolumeshort_ [l=zh] {按册次查阅出版物}
_textdefaultshorttext_ [l=zh] {未定义分类}

_textSearchlong_ [l=zh] {<p>您可以在“查找”页面内的<i>按特定词语查找</i>。此页是显示的第一页，您也可以在其它页按<i>查找</i>键浏览此页。  }

_textTitlelong_ [l=zh] {<p>您可以<i>按标题查阅出版物</i>，请按<i>标题a-z</i>键。 此操作产生按序排列的标题目录。 }

_textOrganizationlong_ [l=zh] {<p>您可以<i>按组织查阅出版物</i>，请按<i>组织</i>键。此操作生成
组织列表。}

_textHowtolong_ [l=zh] {<p>您可以<i>按“如何”功能排列查阅出版物</i>
请按<i>“如何”</i>键。此操作会产生一系列“如何”语句。  }

_textCreatorlong_ [l=zh] {<p>您可以<i>按作者查阅出版物</i>，请按
<i>作者索引a-z</i> 键。 此项操作会列出所有按作者名字排列的书。 }

_textTopiclong_ [l=zh] {<p>您可以<i>按论题查阅出版物</i>，请按<i>论题</i>键。 此操作产生可浏览的论题目录。 }

_textSubjectlong_ [l=zh] {<p>您可以<i>按主题查阅出版物</i>，请按<i>主题</i>键。 此操作产生书架排列的主题目录。 }

_textTolong_ [l=zh] {<p>您可以<i>按“To"选项查阅出版物</i>，请按<i>to</i>键。 此操作产生地址目录。 }

_textFromlong_ [l=zh] {<p>您可以<i>按From查阅</i>，请按
<i>from</i> 键。 此项操作会列出送出人。 }

_textSerieslong_ [l=zh] {<p>您可以<i>按丛书查阅出版物</i>， 请按<i>丛书</i>键。此操作产生收藏内的丛书列表。  }

_textDatelong_ [l=zh] {<p>您可以<i>按日期查阅出版物</i>，请按
<i>日期</i> 键。 此项操作会列出所有按日期排列的书。 }

_textBrowselong_ [l=zh] {<p>您可以<i>浏览出版物</i>， 请按
<i>浏览</i>键。}

_textPeoplelong_ [l=zh] {<p>您可以<i>按人物查阅出版物</i>，请按<i>人物</i>键。此操作生成
人物姓氏列表。}

_textLanguagelong_ [l=zh] {<p>您可以<i>按语言查阅出版物</i>， 请按
<i>语言</i>键。此操作生成按语言排序的纪录。  }

_textAcronymlong_ [l=zh] {<p>您可以<i>按词头查阅出版物</i>， 请按
<i>词头</i>键。此操作会列出所有词头和它们出现的位置。  }

_textPhraselong_ [l=zh] {<p>您可以<i>按短语出现查阅出版物</i>，请按<i>短语</i>键。此操作使用“Phild"短语浏览器。}

_textArtistlong_ [l=zh] {<p>您可以<i>按作者查阅出版物</i>， 请按
<i>作者</i>键。 此操作会列出所有按作者名字排列的记录。}

_textSourcelong_ [l=zh] {<p>您可以<i>按文件名查阅出版物</i>，请按<i>文件名</i>键。 此操作产生按原始文件名排列的目录。 }

_textKeywordlong_ [l=zh] {<p>您可以<i>按关键词查阅出版物</i> 
请按<i>关键词</i> 键。此操作会产生关键词列表。 }

_textVolumelong_ [l=zh] {<p>您可以<i>按册次查阅出版物</i>，请按<i>册次</i>键。 此操作产生册次目录。 }

_textdefaultlongtext_ [l=zh] {<p>请点击<i>未知</i>键浏览出版物(目录按一个未知选项排序)。}

_texthelptopics_ [l=zh] {<h2 align=left>目录</h2>
<ul>
  <li><a href="\#finding-information">_textsimplehelpheading_</a>
   _topicreadingdocs_
  <li><a href="\#searching"> 如何按特定字查询</a>
<ul>
  <li><a href="\#query-terms">检索项</a>
  <li><a href="\#query-type">查询类型</a>
  <li><a href="\#scope-of-queries">查询范围</a>
</ul>
<li><a href="\#preferences">_textchangeprefs_</a>
<ul>
  <li><a href="\#col-prefs">收藏选项</a>
  <li><a href="\#lang-prefs">语言选项</a>
  <li><a href="\#pres-prefs">表达方式选项</a>
  <li><a href="\#search-prefs">查找选项</a>
</ul></ul>
}

# there are 4 versions of this section of the help text.
# which version is used is currently set within the server
# (it should probably use the macro language e.g. [type=book])
# 1 = html (like fao collections) -- section is empty
# 2 = book (like hdl collection) -- macros beginning with book
# 3 = bibliographic (like csbib) -- macros beginning with bib
# 4 = standard (like gberg) -- the default

_topicreadingdocs_ [l=zh] {<li><a href="\#reading-docs">_textreadingdocs_</a>}

_textreadingdocs_ [l=zh] {如何阅读文档}

_texthelpreadingdocs_ [l=zh] {<h2>如何阅读书目</h2>

<p>   当进入某一书目时，通过封面或图片，你可得知屏幕正在显示哪一个书目，封面旁边是目录表，箭头指明此时所处位置。该目录表是可扩展的，单击此目录表，可实现打开或关闭，单击顶部打开的书目以关闭它。</p>
<p>目录表下面是当前部份的文本，在此之后有两个箭头分别指向下一部份或前一部份文本。</p>

<p>在封面下方有三个按键，单击<i>“分离”</i>，则打开另一浏览窗显示该屏幕（这个功能在想要比较不同的书或同时阅读两本书时是有帮助的）；单击“扩展内容”以得到整个书目表，从而看到所有章节的目录；单击“扩展文本”可获得当前章节或书目的全部文本，如果是一本很长的书，可能会需要较长的时间以及大量的内存。
}

_texthelpsearching_ [l=zh] {<h2>如何按特定字查询</h2>
<p>
从查询页，按以下简单的步骤输入查询项：<p>
  
  <ol><li>指明想要查询的文件
      <li>选择是查询所有字还是部份字
      <li>输入要查询的字
      <li>单击“开始查询”
  </ol>

<p>进行查询后，第一组２０个匹配上的记录的题名会显示出来，在此２０个题名之后有一按键可以指向下一组２０个记录的题名，从该屏幕你可看到两个按键，一个按键进一步指向第三组２０个记录的题名，另外一个按键用来返回上一组题名。单击任一书目的题名或其旁边的小按键，就可进行阅读这条记录的详细内容。

<p>最多返回１００条记录，如要改变该数目，则单击页面右上方的“选项”

<p>
<a name=query-terms>
_iconblankbar_<br>

<h2>检索项</h2>

<p>输入到查询框中的内容，将被转化成一个叫做查询项的单字集，查询项可以是汉字、阿拉伯字母或数字，查询项之间可以有空格，也可以没有。如果遇到其他的符号，例如标点符号，则会被忽略，并将它们看作空格处理，因此不能查询包含标点符号的词。

<p>例如：查询<p>
    <ul><kbd>    内容包括：软件工程（1999）</kbd></ul>
      <p>与下面的查询项处理是相同的<p>
      <ul><kbd>　　内容包括软件工程1999</kbd></ul><p>

<a name=query-type>
_iconblankbar_<br>

<h2>查询类型</h2>

<p><ul>可以按两种不同的方式查询：<p>

  <li>查询所有的字。在这种情况下系统将查找包括所有在查询项指定的字的记录（或题名）。符合条件的记录将被显示在屏幕上。

  <li>查询部份字。系统仅查找包含查询项中任意一个或几个字的记录，文件按其与查询内容所匹配的程度来显示，在决定匹配程度时：

      <p><ul>
        <li> 　包含越多的查询项的记录，其匹配程度越高；
        <li> 　少见的查询项比常见的查询项更重要；
        <li> 　短记录比长记录的匹配程度高。
      </ul>

      <p>在可能的情况下，使用尽可能多的查询项为好，一个句子，或者一个段落。如果只给一个查询项，查询结果将按照其在记录中出现的频率进行排序。
      
</ul>

<p>
<a name=other-options><a name=scope-of-queries>
_iconblankbar_<br>
_texthelpscope_
}

_textdatesearch_ [l=zh] {带日期查询}

# -- Missing translation: _texthelpdatesearch_

_textchangeprefs_ [l=zh] {修改您的选项}

_texthelppreferences_ [l=zh] {<h2>_textchangeprefs_</h2>

<p>当点击本页上部的<i>选项</i>您可以根据您的要求修改界面的某些特性。

<p>_iconblankbar_
<a name=col-prefs>
<h3 align=left>收藏选项</h3>

某些收藏由几个下级收藏组成，您可以单独或全部查询它们。
您可以在选项页选择合适的下级收藏来进行查询。

<p>_iconblankbar_
<a name=lang-prefs>
<h3 align=left>语言选项</h3> 
每个收藏有预先设定的语言，但是您可以选择您喜欢的语言。您还可以改变绿宝石软件为输出到浏览器采用的预设的编码系统配置，但是有些浏览器可以采用不同的编码系统配置而获得更好的视觉效果。所用的收藏允许您从标准的图形界面转到文字界面。这对于视觉有缺陷而使用大显示字体或语言识别器的用户特别有好处。

<p>_iconblankbar_
<a name=pres-prefs>
<h3 align=left>表达方式选项</h3>
对于特别的收藏，您可以有几种选项来控制表达方式。

<p>网页收藏允许您不显示在每个文件头的绿宝石软件的导航条，这样您可以直接浏览所匹配的网页，而不显示任何绿宝石软件的页首。您可以用浏览器的“后退”键进行下一次的查找。当您点击某个连接而离开数字图书馆的时候，这些收藏还允许您不显示绿宝石软件的警告信息。在有些网页收藏中您可以控制在"查询结果"页是否直接链接到实际的URL,还是数字图书馆的备份.

<p>_iconblankbar_
<a name=search-prefs>
<h3 align=left>查询选项</h3>
<p>两对按键控制您的查询匹配的文字.第一对(标有"区别大小写")控制是否大小写必须匹配. 第二对("词语结尾")控制是否忽略词语结尾. 这可能获得大的查询框,这样的话您可以很容易得进行段落查询. 您可能会对大量的文字的快速查询的速度感到惊讶.

<p>例如,如果按键<i>忽略大小写</i>和
<i>忽略词语结尾</i>被选择了的话, 查询<p>
    <ul><kbd>African building</kbd></ul>
      <p>将会和<p>
      <ul><kbd>africa builds</kbd></ul>一样对待.<p>
      这是因为大写字符"African"将会转化成小写, 并且"African"的结尾"n"和"building"的结尾"ing" 将会被去掉("s" 将会从"builds"中被去掉).

<p>您可以从采用"高级"查询方式, 它允许您结合词语AND (&), OR (|), 和 NOT (!)来进行高级查找. 这样您可以定义更精确的查询.您还可以打开查询历史功能, 查询历史会显示您最近的几次查询, 这样可以更简单的进行和以前前稍微不同的查询. 最后,您可以控制查找结果的数量和每屏显示的结果数量.
}

_texttanumbrowseoptions_ [l=zh] {在本收藏内共有_numbrowseoptions_方法来查询信息:}

_textsimplehelpheading_ [l=zh] {如何在_collectionname_收藏内查找信息}

_texthelpscope_ [l=zh] {<h2 align=left>查询范围</h2>

<p>
您可以选择在不同的索引进行查询. 例如按作者和标题查询, 或者章节和段落索引。一般来说,
无论在什么范围内进行查询，查询结果都将是匹配的整个文档。<p>如果文档是书籍的话,那么文档会在合适的位置打开.
}
